<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests;
use App\Http\Controllers\Controller;
use App\Models\Admin;

use App\Models\Message;

use App\Models\Package;
use App\Models\Setting;
use App\Models\City;

use App\Models\Bank;

use App\Models\AdminRole;
use App\Models\Permission;
use App\Models\Role;
use App\Models\RolePermission;
use App\Models\Transfer;
use App\User;
use Illuminate\Http\Request;
use Auth;

abstract class MasterController extends Controller
{

    protected $model;         // model name
//  protected $language;         // number of languages
    protected $modelDescription;         // modelDescription name
    protected $modelImage;         // modelImage name
    protected $description_fields;         // modelDescription fields
    protected $descriptions;         // modelDescription fields
    protected $other_model;         // other_model name
    protected $route;         // route name
    protected $perPage = 10;  // pagination
    protected $validation_c;  // validation on create
    protected $validation_u;  // validation on update
    protected $module_name;
    protected $single_module_name;
    protected $index_fields;
    protected $create_fields;
    protected $update_fields;

    public function __construct()
    {

//        $cities_array = [];
//        $cities = City::all();
//        foreach ($cities as $city) {
//            $cities_array[$city->id] = $city->name['ar'];
//        }


        $user_array = [];
        $users = User::all();
        foreach ($users as $user) {
            $user_array[$user->id] = $user->name;
        }


        $this->middleware('auth:admin');
        view()->share(array(
            'module_name' => $this->module_name,
            'single_module_name' => $this->single_module_name,
            'route' => $this->route,
            'languages' => ['ar' => ' بالعربية', 'en' => ' بالانجليزية'],
            'index_fields' => $this->index_fields,
            'create_fields' => $this->create_fields,
            'update_fields' => $this->update_fields,
            'descriptions' => $this->descriptions,
            'description_fields' => $this->description_fields,
            'modelDescription' => $this->modelDescription,
            'user_array' => $user_array,
//            'cities_array' => $cities_array,
            'status' => ['active' => 'مفعل', 'not_active' => 'غير مفعل'],
//          'languages'    => Language::all(),
            'setting' => Setting::first(),
            'admin_count' => Admin::count(),
            'user_count' => User::count(),
//            'city_count' => City::count(),
            'message_count' => Message::count(),
            'bank_count' => Bank::count(),
            'packages_count' => Package::count(),
            'transfers_count' => Transfer::count(),

        ));
    }

    public function index()
    {
        $rows = $this->model->latest()->get();
        return view('admin.' . $this->route . '.index', compact('rows'));
    }

    public function create()
    {
        return view('admin.' . $this->route . '.create');
    }

    public function store(Request $request)
    {
        $this->validate($request, $this->validation_func(1));
        $obj = $this->model->create($request->all());


        return redirect('admin/' . $this->route . '')->with('created', 'تمت الاضافة بنجاح');
    }

    public function edit($id)
    {
        $row = $this->model->find($id);

        return View('admin.' . $this->route . '.edit', compact('row'));
    }

    public function update($id, Request $request)
    {
        $this->validate($request, $this->validation_func(2, $id));
        $this->model->find($id)->update($request->all());

        return redirect('admin/' . $this->route . '')->with('updated', 'تم التعديل بنجاح');
    }

    public function destroy($id)
    {
        $this->model->find($id)->delete();
        return redirect('admin/' . $this->route . '')->with('deleted', 'تم الحذف بنجاح');
    }

    public function show($id)
    {
        $row = $this->model->find($id);
        return View('admin.' . $this->route . '.show', compact('row'));
    }

    public function Activate($id)
    {
        $row = $this->model->find($id);
        if ($row->status == 'not_active') {
            $this->model->find($id)->update(['status' => 'active']);
            return back()->with('success', 'تم الغاء التفعيل بنجاح');
        } else {
            $this->model->find($id)->update(['status' => 'not_active']);
            return back()->with('success', 'تم التفعيل بنجاح');
        }
    }

}

